@@ -1,4 +1,4 @@
-# Copyright 2016-2021 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
+# Copyright 2016-2022 Swiss National Supercomputing Centre (CSCS/ETH Zurich)
 # ReFrame Project Developers. See the top-level LICENSE file for details.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -10,6 +10,7 @@ import reframe.core.fields as fields
 import reframe.utility as util
 import reframe.utility.jsonext as jsonext
 import reframe.utility.typecheck as typ
+from reframe.core.warnings import user_deprecation_warning
 
 
 def normalize_module_list(modules):
@@ -37,14 +38,24 @@ class Environment(jsonext.JSONSerializable):
        Users may not create :class:`Environment` objects directly.
     '''
 
-    def __init__(self, name, modules=None, variables=None, extras=None):
+    def __init__(self, name, modules=None, env_vars=None,
+                 extras=None, features=None):
         modules = modules or []
-        variables = variables or []
+        env_vars = env_vars or []
         self._name = name
         self._modules = normalize_module_list(modules)
         self._module_names = [m['name'] for m in self._modules]
-        self._variables = collections.OrderedDict(variables)
+
+        # Convert values of env_vars to strings before storing
+        if isinstance(env_vars, dict):
+            env_vars = env_vars.items()
+
+        self._env_vars = collections.OrderedDict()
+        for k, v in env_vars:
+            self._env_vars[k] = str(v)
+
         self._extras = extras or {}
+        self._features = features or []
 
     @property
     def name(self):
@@ -83,16 +94,29 @@ class Environment(jsonext.JSONSerializable):
         return util.SequenceView(self._modules)
 
     @property
-    def variables(self):
+    def env_vars(self):
         '''The environment variables associated with this environment.
 
         :type: :class:`OrderedDict[str, str]`
+
+        .. versionadded:: 4.0.0
         '''
-        return util.MappingView(self._variables)
+        return util.MappingView(self._env_vars)
+
+    @property
+    def variables(self):
+        '''The environment variables associated with this environment.
+
+        .. deprecated:: 4.0.0
+           Please :attr:`env_vars` instead.
+        '''
+        user_deprecation_warning("the 'variables' attribute is deprecated; "
+                                 "please use the 'env_vars' instead")
+        return util.MappingView(self._env_vars)
 
     @property
     def extras(self):
-        '''User defined properties defined in the configuration.
+        '''User defined properties specified in the configuration.
 
         .. versionadded:: 3.9.1
 
@@ -101,13 +125,33 @@ class Environment(jsonext.JSONSerializable):
 
         return self._extras
 
+    @property
+    def features(self):
+        '''Used defined features specified in the configuration.
+
+        .. versionadded:: 3.11.0
+
+        :type: :class:`List[str]`
+        '''
+        return self._features
+
     def __eq__(self, other):
         if not isinstance(other, type(self)):
             return NotImplemented
 
-        return (self.name == other.name and
-                set(self.modules) == set(other.modules) and
-                self.variables == other.variables)
+        if (self.name != other.name or
+            set(self.modules) != set(other.modules)):
+            return False
+
+        # Env. variables are checked against their string representation
+        for kv0, kv1 in zip(self.env_vars.items(),
+                            other.env_vars.items()):
+            k0, v0 = kv0
+            k1, v1 = kv1
+            if k0 != k1 or str(v0) != str(v1):
+                return False
+
+        return True
 
     def __str__(self):
         return self.name
@@ -116,7 +160,8 @@ class Environment(jsonext.JSONSerializable):
         return (f'{type(self).__name__}('
                 f'name={self._name!r}, '
                 f'modules={self._modules!r}, '
-                f'variables={list(self._variables.items())!r})')
+                f'env_vars={list(self._env_vars.items())!r}, '
+                f'extras={self._extras!r}, features={self._features!r})')
 
 
 class _EnvironmentSnapshot(Environment):
@@ -128,15 +173,15 @@ class _EnvironmentSnapshot(Environment):
     def restore(self):
         '''Restore this environment snapshot.'''
         os.environ.clear()
-        os.environ.update(self._variables)
+        os.environ.update(self._env_vars)
 
     def __eq__(self, other):
         if not isinstance(other, Environment):
             return NotImplemented
 
-        # Order of variables is not important when comparing snapshots
-        for k, v in self.variables.items():
-            if other.variables[k] != v:
+        # Order of env. variables is not important when comparing snapshots
+        for k, v in self.env_vars.items():
+            if other.env_vars[k] != v:
                 return False
 
         return self.name == other.name
@@ -172,8 +217,9 @@ class ProgEnvironment(Environment):
     def __init__(self,
                  name,
                  modules=None,
-                 variables=None,
+                 env_vars=None,
                  extras=None,
+                 features=None,
                  cc='cc',
                  cxx='CC',
                  ftn='ftn',
@@ -184,7 +230,7 @@ class ProgEnvironment(Environment):
                  fflags=None,
                  ldflags=None,
                  **kwargs):
-        super().__init__(name, modules, variables, extras)
+        super().__init__(name, modules, env_vars, extras, features)
         self._cc = cc
         self._cxx = cxx
         self._ftn = ftn
