@@ -14,7 +14,6 @@ import re
 import time
 import xml.etree.ElementTree as ET
 
-import reframe.core.runtime as rt
 import reframe.utility.osext as osext
 from reframe.core.backends import register_scheduler
 from reframe.core.exceptions import JobSchedulerError
@@ -28,9 +27,7 @@ _run_strict = functools.partial(osext.run_command, check=True)
 class SgeJobScheduler(PbsJobScheduler):
     def __init__(self):
         self._prefix = '#$'
-        self._submit_timeout = rt.runtime().get_option(
-            f'schedulers/@{self.registered_name}/job_submit_timeout'
-        )
+        self._submit_timeout = self.get_option('job_submit_timeout')
 
     def emit_preamble(self, job):
         preamble = [
