@@ -935,7 +935,7 @@ def main():
             elif len(optstr) == 1:
                 parsed_job_options.append(f'-{optstr} {valstr}')
             else:
-                parsed_job_options.append(f'--{optstr} {valstr}')
+                parsed_job_options.append(f'--{optstr}={valstr}')
 
         # Locate and load checks; `force=True` is not needed for normal
         # invocations from the command line and has practically no effect, but
@@ -999,6 +999,15 @@ def main():
             f'{len(testcases)} remaining'
         )
 
+        # Warn on any unset test variables for the final set of selected tests
+        for clsname in {type(tc.check).__name__ for tc in testcases}:
+            varlist = ', '.join(f'{v!r}' for v in loader.unset_vars(clsname))
+            if varlist:
+                printer.warning(
+                    f'test {clsname!r}: '
+                    f'the following variables were not set: {varlist}'
+                )
+
         # Filter in failed cases
         if options.failed:
             if options.restore_session is None:
