@@ -60,9 +60,13 @@ class RegressionCheckLoader:
 
         # Variables set in the command line
         self._external_vars = external_vars or {}
+        self._unset_vars = {}
         self._skip_system_check = bool(skip_system_check)
         self._skip_prgenv_check = bool(skip_prgenv_check)
 
+    def unset_vars(self, testname):
+        return self._unset_vars.get(testname, [])
+
     def _module_name(self, filename):
         '''Figure out a module name from filename.
 
@@ -133,7 +137,7 @@ class RegressionCheckLoader:
         if test_registry is None:
             return
 
-        unset_vars = {}
+        self._unset_vars = {}
         for test in test_registry:
             for name, val in self._external_vars.items():
                 if '.' in name:
@@ -149,16 +153,8 @@ class RegressionCheckLoader:
                         val = fields.make_convertible(val)
 
                     if not test.setvar(varname, val):
-                        unset_vars.setdefault(test.__name__, [])
-                        unset_vars[test.__name__].append(varname)
-
-        # Warn for all unset variables
-        for testname, varlist in unset_vars.items():
-            varlist = ', '.join(f'{v!r}' for v in varlist)
-            getlogger().warning(
-                f'test {testname!r}: '
-                f'the following variables were not set: {varlist}'
-            )
+                        self._unset_vars.setdefault(test.__name__, [])
+                        self._unset_vars[test.__name__].append(varname)
 
     def load_from_module(self, module):
         '''Load user checks from module.
@@ -166,20 +162,8 @@ class RegressionCheckLoader:
         This method tries to load the test registry from a given module and
         instantiates all the tests in the registry. The instantiated checks
         are validated before return.
-
-        For legacy reasons, a module might have the additional legacy registry
-        `_rfm_gettests`, which is a method that instantiates all the tests
-        registered with the deprecated `parameterized_test` decorator.
         '''
-        from reframe.core.pipeline import RegressionTest
-
-        # FIXME: Remove the legacy_registry after dropping parameterized_test
         registry = getattr(module, '_rfm_test_registry', None)
-        legacy_registry = getattr(module, '_rfm_gettests', None)
-        if not any((registry, legacy_registry)):
-            getlogger().debug('No tests registered')
-            return []
-
         self._set_defaults(registry)
         reset_sysenv = self._skip_prgenv_check << 1 | self._skip_system_check
         if registry:
@@ -187,32 +171,9 @@ class RegressionCheckLoader:
         else:
             candidate_tests = []
 
-        legacy_tests = legacy_registry() if legacy_registry else []
-        if self._external_vars and legacy_tests:
-            getlogger().warning(
-                "variables of tests using the deprecated "
-                "'@parameterized_test' decorator cannot be set externally; "
-                "please use the 'parameter' builtin in your tests"
-            )
-
-        # Reset valid_systems and valid_prog_environs in all legacy tests
-        if reset_sysenv:
-            for t in legacy_tests:
-                if self._skip_system_check:
-                    t.valid_systems = ['*']
-
-                if self._skip_prgenv_check:
-                    t.valid_prog_environs = ['*']
-
-        # Merge tests
-        candidate_tests += legacy_tests
-
         # Post-instantiation validation of the candidate tests
         final_tests = []
         for c in candidate_tests:
-            if not isinstance(c, RegressionTest):
-                continue
-
             if not self._validate_check(c):
                 continue
 
